#
# spec file for package python-blinker
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-blinker
Version:        1.9.0
Release:        1.4
Summary:        Object-to-object and broadcast signaling in Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/pallets-eco/blinker/
Source:         https://files.pythonhosted.org/packages/source/b/blinker/blinker-%{version}.tar.gz
Patch1:         remove-sphinxextensions.patch
BuildRequires:  %{python_module Pallets-Sphinx-Themes}
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module sphinx-issues}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Blinker provides a dispatching system that allows any number of
interested parties to subscribe to events, or "signals".

Signal receivers can subscribe to specific senders or receive signals
sent by any sender.

%if 0%{?suse_version} > 1500
%package -n python-blinker-doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML
BuildRequires:  %{python_module Pallets-Sphinx-Themes}
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module sphinxcontrib-htmlhelp}
BuildRequires:  %{python_module sphinxcontrib-jsmath}
BuildRequires:  %{python_module sphinxcontrib-serializinghtml}
Provides:       %{python_module blinker-doc = %{version}}

%description -n python-blinker-doc
Blinker provides a dispatching system that allows any number of
interested parties to subscribe to events, or "signals".

Signal receivers can subscribe to specific senders or receive signals
sent by any sender.

This sub-package contains the HTML documentation.
%endif

%prep
%autosetup -p1 -n blinker-%{version}

%build
%pyproject_wheel

%install
%pyproject_install

%{python_expand pushd docs
export PYTHONPATH=%{buildroot}%{$python_sitelib}
# Do not call "make html" directly because it'll use python3 by
# default and that could produce .pyc files from different python
# versions in the package bsc#1213698
$python -m sphinx -M html . _build
popd

%fdupes %{buildroot}%{$python_sitelib}
}

%check
%pytest

%files %{python_files}
%license LICENSE.txt
%doc CHANGES.rst README.md
%{python_sitelib}/blinker-%{version}*-info
%{python_sitelib}/blinker

%if 0%{?suse_version} > 1500
%files -n python-blinker-doc
%endif
%doc docs/_build/html

%changelog
* Tue Nov 19 2024 Dirk Müller <dmueller@suse.com>
- update to 1.9.0:
  * Drop support for Python 3.8. :pr:`175`
  * Remove previously deprecated __version__, receiver_connected,
    Signal.temporarily_connected_to and WeakNamespace. :pr:`172`
  * Skip weakref signal cleanup if the interpreter is shutting
    down. :issue:`173`
* Sun Nov  3 2024 ecsos <ecsos@opensuse.org>
- Add missing build require pallets_sphinx_themes
  to fix build error under Leap.
* Tue Oct 22 2024 Dirk Müller <dmueller@suse.com>
- update to 1.8.2:
  * Simplify type for _async_wrapper and _sync_wrapper arguments.
    :pr:`156`
  * Restore identity handling for str and int senders. :pr:`148`
  * Fix deprecated blinker.base.WeakNamespace import. :pr:`149`
  * Fix deprecated blinker.base.receiver_connected import.
    :pr:`153`
  * Use types from collections.abc instead of typing. :pr:`150`
  * Fully specify exported types as reported by pyright.
    :pr:`152`
  * Deprecate the __version__ attribute. Use feature detection,
    or importlib.metadata.version("blinker"), instead.
    :issue:`128`
  * Specify that the deprecated temporarily_connected_to will be
    removed in the next version.
  * Show a deprecation warning for the deprecated global
    receiver_connected signal and specify that it will be removed
    in the next version.
  * Show a deprecation warning for the deprecated WeakNamespace
    and specify that it will be removed in the next version.
  * Greatly simplify how the library uses weakrefs. This is a
    significant change internally but should not affect any
    public API. :pr:`144`
  * Expose the namespace used by signal() as default_namespace.
    :pr:`145`
- add remove-sphinxextensions.patch to remove an optional
  sphinxextension
* Tue Nov 14 2023 Benoît Monin <benoit.monin@gmx.fr>
- update to version 1.7.0:
  * Fixed messages printed to standard error about unraisable
    exceptions during signal cleanup, typically during interpreter
    shutdown. #123
  * Allow the Signal set_class to be customised, to allow calling
    of receivers in registration order. #116.
  * Drop Python 3.7 and support Python 3.12. #126
- additional changes from 1.6.3:
  * Fix SyncWrapperType and AsyncWrapperType #108
  * Fixed issue where signal.connected_to would not disconnect the
    receiver if an instance of BaseException was raised. #114
- require python >= 3.8: upstream dropped 3.7 support
- drop setuptools and wheel, add flit-core as BuildRequires:
  upstream switched build system
* Mon Jul 31 2023 Daniel Garcia <daniel.garcia@suse.com>
- Remove no-stdpy-pyc.patch
- Call directly to the sphinx module with the specific python
  interpreter to avoid the usage of default python, bsc#1213698.
* Wed Jul 26 2023 Matej Cepl <mcepl@suse.com>
- Add no-stdpy-pyc.patch which makes Sphinx not to generate
  * .pyc files for the Python interpreter it uses for generating
  documentation.
* Tue May  9 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update to 1.6.2:
  * Type annotations are not evaluated at runtime. typing-extensions
    is not a runtime dependency. :pr:`94`
- 1.6.1:
  * Ensure that py.typed is present in the distributions (to enable
    other projects to use blinker's typing).
  * Require typing-extensions > 4.2 to ensure it includes ParamSpec.
    :issue:`90`
- 1.6:
  * Add a muted context manager to temporarily turn off a signal.
    :pr:`84`
  * Allow int senders (alongside existing string senders). :pr:`83`
  * Add a send_async method to the Signal to allow signals to send to
    coroutine receivers. :pr:`76`
  * Update and modernise the project structure to match that used by
    the pallets projects. :pr:`77`
  * Add an intial set of type hints for the project.
* Sun Apr 23 2023 Matej Cepl <mcepl@suse.com>
- move documentation into the main package for SLE15
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Wed Sep 14 2022 Matej Cepl <mcepl@suse.com>
- Fix documentation generation.
* Mon Sep 12 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * remove patch python-blinker-remove-nose.patch; included upstream
  * docs and license changed to .rst
  * build docs using Sphinx
- update to version 1.5:
  * Support Python >= 3.7 and PyPy. Python 2, Python < 3.7, and Jython
    may continue to work, but the next release will make incompatible
    changes.
* Wed Jul  8 2020 pgajdos@suse.com
- use pytest instead of deprecated nose
- added patches
  https://github.com/jek/blinker/pull/60
  + python-blinker-remove-nose.patch
* Thu Dec  6 2018 Tomáš Chvátal <tchvatal@suse.com>
- Fix fdupes call
* Wed Dec  5 2018 Jan Engelhardt <jengelh@inai.de>
- Trim bias from description.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun May  7 2017 benoit.monin@gmx.fr
- convert the package to singlespec
- call fdupes to fix duplicated files
- remove unneeded buildrequires: unzip
- remove unneded doc file that trigger rpmlint
- put the documentation in a separate sub-package
* Thu Sep 15 2016 rjschwei@suse.com
- Include in SLES 12 (FATE#321371, bsc#998103)
* Fri Mar 11 2016 freitag@opensuse.org
- use setup.py option to record file list for rpm package
* Sun Jan  3 2016 freitag@opensuse.org
- Fixed doc section in file list
* Sun Jan  3 2016 freitag@opensuse.org
- update to version 1.4:
  * Verified Python 3.4 support (no changes needed)
  * Additional bookkeeping cleanup for non-ANY connections at disconnect
    time.
  * Added Signal._cleanup_bookeeping() to prune stale bookkeeping on
    demand
* Sun Feb 22 2015 benoit.monin@gmx.fr
- update to version 1.3:
  * The global signal stash behind blinker.signal() is now backed
    by a regular name-to-Signal dictionary
  * blinker.Namespace is now built on a regular dict
  * Signal.connect('text-sender') uses an alterate hashing strategy
    to avoid sharp edges in text identity.
* Wed Aug 15 2012 highwaystar.ru@gmail.com
- python3 package added
- spec improved (files section)
* Fri Jun 22 2012 saschpe@suse.de
- Update to version 1.2:
  + Added Signal.receiver_connected and
    Signal.receiver_disconnected per-Signal signals.
  + Deprecated the global 'receiver_connected' signal.
  + Verified Python 3.2 support (no changes needed!)
* Fri Sep 23 2011 saschpe@suse.de
- Initial version
